# TACC CMS - Cortal Icons Font

SYNC THIS FONT HERE WITH CMS & PORTAL & DOCS!

This file is a clone from Portal and it must be in sync with its [origin file][origin].

[origin]: https://github.com/TACC/Frontera-Portal/blob/master/client/src/styles/trumps/icon.fonts.css
